/************************************************************************
 *  This file is part of assets-cli.
 *
 *  assets-cli is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 * assets-cli is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with assets-cli.  If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/

#include <stdlib.h>
#include <string.h>

#include "asset.h"

/**
 * @brief Calculates the deprication for the financial accounting
 * @param asset The asset struct
 */
static float get_deprication_finanical(struct asset* asset);

/**
 * @brief Calculates the deprication for the cost accounting
 * @param asset The asset struct
 */
static float get_deprication_cost(struct asset* asset);


struct asset* asset_create(float acquisition_costs,
                     float years_of_service,
                     char* account)
{
  struct asset* asset;

  asset = malloc(sizeof(struct asset*));

  /* asset->_years_of_service = years_of_service; */
  asset->_acquisition_costs = acquisition_costs;
  asset->_account = malloc(sizeof(char) * strlen(account));
  strcpy(asset->_account, account);

  return asset;
}

extern void asset_free(struct asset* asset)
{
  free(asset->_account);
  free(asset);
}

float asset_get_deprication(struct asset* asset,
                      enum deprication_kind deprication_kind,
                      time_t start_date,
                      time_t end_date)
{
  float deprication;

  switch(deprication_kind) {
  default:
  case FINANCIAL_ACCOUNTING:
    deprication = get_deprication_finanical(asset);
    break;
  case COST_ACCOUNTING:
    deprication = get_deprication_cost(asset);
    break;
  }

  return deprication;
}

float get_deprication_finanical(struct asset* asset)
{
  return asset->_acquisition_costs;
}

float get_deprication_cost(struct asset* asset)
{
  return asset->_acquisition_costs;
}
