/************************************************************************
 *  This file is part of assets-cli.
 *
 *  assets-cli is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 * assets-cli is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with assets-cli.  If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/

/**
 * @file doxygen_c.h
 * @author Richard Bäck
 * @date 2 Feb 2015
 * @brief File contains the "asset" struct
 */

#ifndef ASSET_H
#define ASSET_H

#include <time.h>

struct asset
{
  float _acquisition_costs;
  time_t _bringing_into_service;
  char* _account;
  float _years_of_service;
};

enum deprication_kind
  {
    FINANCIAL_ACCOUNTING,
    COST_ACCOUNTING
  };

/**
 * @brief The constructor for an asset struct.
 * @param cost The acquisition costs for this asset
 * @param years_of_service The years an asset is in service.
 * @param account The name of the account for this asset
 * @return A fresh asset
 */
extern struct asset* asset_create(float acquisition_costs,
                            float years_of_service,
                            char* account);

/**
 * @brief The destructor of an asset struct.
 * @param asset The asset struct to delete.
 */
extern void asset_free(struct asset* asset);

/**
 * @brief Calculates the deprication
 * @param asset The asset struct
 * @param deprication_kind The kind of wanted deprication (either for the financial or the cost accounting).
 * @param start_date The start date of a period. If NULL is supplied the beginning of the year financial year is used as the start date.
 * @param end_date The end date of a period. If NULL is supplied the end of the financial year is used.
 * @return The deprication for the period
 */
extern float asset_get_deprication(struct asset* asset,
                             enum deprication_kind deprication_kind,
                             time_t start_date,
                             time_t end_date);

#endif /* ASSET_H */
